@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2021 -- leonerd@leonerd.org.uk
 
-package Object::Pad::ExtensionBuilder 0.809;
+package Object::Pad::ExtensionBuilder 0.810;
 
 use v5.14;
 use warnings;
@@ -37,8 +37,6 @@ distribution to be able to compile it.
 
 =cut
 
-require Object::Pad::ExtensionBuilder_data;
-
 =head1 METHODS
 
 =cut
@@ -47,19 +45,12 @@ require Object::Pad::ExtensionBuilder_data;
 
    Object::Pad::ExtensionBuilder->write_object_pad_h;
 
-Writes the F<object_pad.h> file to the current working directory. To cause
-the compiler to actually find this file, see L</extra_compiler_flags>.
+This method no longer does anything I<since version 0.810>.
 
 =cut
 
 sub write_object_pad_h
 {
-   shift;
-
-   open my $out, ">", "object_pad.h" or
-      die "Cannot open object_pad.h for writing - $!\n";
-
-   $out->print( Object::Pad::ExtensionBuilder_data->OBJECT_PAD_H );
 }
 
 =head2 extra_compiler_flags
@@ -75,7 +66,11 @@ F<object_pad.h> file.
 sub extra_compiler_flags
 {
    shift;
-   return "-I.";
+
+   require File::ShareDir;
+   require File::Spec;
+   require Object::Pad;
+   return "-I" . File::Spec->catdir( File::ShareDir::module_dir( "Object::Pad" ), "include" );
 }
 
 =head2 extend_module_build
@@ -92,11 +87,6 @@ sub extend_module_build
    my $self = shift;
    my ( $build ) = @_;
 
-   eval { $self->write_object_pad_h } or do {
-      warn $@;
-      return;
-   };
-
    # preserve existing flags
    my @flags = @{ $build->extra_compiler_flags };
    push @flags, $self->extra_compiler_flags;
